import React, { useState } from "react";
import CustomColorPicker from "@/components/CustomColorPicker";
import {
  Button,
  Checkbox,
  InputNumber,
  Select,
  Form,
  Popover,
  Input,
  Divider,
} from "antd";
import { QuestionCircleOutlined, SwapOutlined } from "@ant-design/icons";
import crossLineImg from "@/assets/image/linejump.png";
import noCrossLineImg from "@/assets/image/unlinejump.png";

export default function PageStyle() {
  const [setting, setSetting] = useState({
    color: "#ffff00",
  });
  return (
    <div>
      <section className="px-16px">
        <div className="flex items-center justify-between px-16px py-8px">
          <div className="flex-1 font-bold">背景样式</div>
          <CustomColorPicker
            color={setting.color}
            onChange={(color) => setSetting({ color })}
          />
        </div>
        <div className="pb-8px">
          <Select
            className="w-full"
            options={[
              { value: "1", label: "A3尺寸(1500px*2100px)" },
              { value: "2", label: "A4尺寸(1050px*1000px)" },
              { value: "3", label: "A5尺寸(700px*1050px)" },
            ]}
          />
        </div>
        <div className="flex justify-between pb-8px">
          <InputNumber
            suffix="W"
            step={1}
            min={500}
            max={10000}
            formatter={(val) => `${val}px`}
          />
          <Button icon={<SwapOutlined />} />
          <InputNumber
            suffix="H"
            step={1}
            min={500}
            max={10000}
            formatter={(val) => `${val}px`}
          />
        </div>
      </section>
      <Divider className="my-8px" />
      <section className="px-16px">
        <div>
          <Checkbox>
            <span className="font-bold">显示网格</span>
          </Checkbox>
        </div>
        <div>
          <Form.Item
            label="网格大小"
            labelCol={{ span: 10 }}
            labelAlign="left"
            className="mb-8px"
            colon={false}
          >
            <Select
              options={[
                { value: "1", label: "小" },
                { value: "2", label: "正常" },
                { value: "3", label: "大" },
                { value: "4", label: "很大" },
              ]}
            />
          </Form.Item>
          <Form.Item
            label="网格尺寸"
            labelCol={{ span: 10 }}
            wrapperCol={{ span: 14 }}
            labelAlign="left"
            className="mb-8px"
            colon={false}
          >
            <InputNumber
              className="w-full"
              step={1}
              min={10}
              max={100}
              formatter={(val) => `${val}px`}
            />
          </Form.Item>
        </div>
      </section>
      <Divider className="my-8px" />
      <section className="px-16px">
        <div>
          <Checkbox>
            <span className="font-bold">显示跨线</span>
          </Checkbox>
          <Popover
            content={
              <div className="flex justify-between">
                <div className="mr-8px">
                  <img src={crossLineImg} alt="" />
                  <div>显示跨线</div>
                </div>
                <div>
                  <img src={noCrossLineImg} alt="" />
                  <div>不显示跨线</div>
                </div>
              </div>
            }
          >
            <QuestionCircleOutlined className="color-#999 hover:color-#666" />
          </Popover>
        </div>
      </section>
      <Divider className="my-8px" />
      <section className="px-16px">
        <div>
          <Checkbox>
            <span className="font-bold">显示打印分割线</span>
          </Checkbox>
        </div>
      </section>
      <Divider className="my-8px" />
      <section className="px-16px">
        <Checkbox className="mb-8px">
          <span className="font-bold">显示水印</span>
        </Checkbox>
        <Input placeholder="不超过15字，回车保存" maxLength={15} />
      </section>
    </div>
  );
}
